==> jupyterlite-xeus-wren-0.1.2.tar.gz: jupyterlite-xeus-wren-0.1.2/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/jupyterlite/xeus-wren-kernel/compare/v0.1.1...812b17e363e3926a2f6534f580374cca6eb73f2b))

### Maintenance and upkeep improvements

- Update links [#7](https://github.com/jupyterlite/xeus-wren-kernel/pull/7) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- using jupyter-xeus/xeus-wren instead of DerThorsten/xeus-wren [#6](https://github.com/jupyterlite/xeus-wren-kernel/pull/6) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-wren-kernel/graphs/contributors?from=2021-10-20&to=2021-10-22&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-wren-kernel+involves%3ADerThorsten+updated%3A2021-10-20..2021-10-22&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-wren-kernel+involves%3Ajtpio+updated%3A2021-10-20..2021-10-22&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-wren-kernel/compare/first-commit...6c1c831b3ece43e40c9725519f2453e8e7efc431))

### Maintenance and upkeep improvements

- Ci [#3](https://github.com/jupyterlite/xeus-wren-kernel/pull/3) ([@DerThorsten](https://github.com/DerThorsten))
- using pinnig in Dockerfile [#1](https://github.com/jupyterlite/xeus-wren-kernel/pull/1) ([@DerThorsten](https://github.com/DerThorsten))

### Documentation improvements

- Update screencast and github actions link [#4](https://github.com/jupyterlite/xeus-wren-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-wren-kernel/graphs/contributors?from=2021-10-07&to=2021-10-20&type=c))

[@DerThorsten](https://github.com/search?q=repo%3ADerThorsten%2Fjupyterlite_xeus_wren+involves%3ADerThorsten+updated%3A2021-10-07..2021-10-20&type=Issues) | [@jtpio](https://github.com/search?q=repo%3ADerThorsten%2Fjupyterlite_xeus_wren+involves%3Ajtpio+updated%3A2021-10-07..2021-10-20&type=Issues)

==> jupyterlite-xeus-wren-0.2.0.tar.gz: jupyterlite-xeus-wren-0.2.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/jupyterlite/xeus-wren-kernel/compare/v0.1.2...ebfe2958b258bd739421507078290d758b111cd5))

### Merged PRs

- Update to xeus-wren 0.3.3 [#9](https://github.com/jupyterlite/xeus-wren-kernel/pull/9) ([@SylvainCorlay](https://github.com/SylvainCorlay))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-wren-kernel/graphs/contributors?from=2021-10-22&to=2022-03-17&type=c))

[@SylvainCorlay](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-wren-kernel+involves%3ASylvainCorlay+updated%3A2021-10-22..2022-03-17&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/jupyterlite/xeus-wren-kernel/compare/v0.1.1...812b17e363e3926a2f6534f580374cca6eb73f2b))

### Maintenance and upkeep improvements

- Update links [#7](https://github.com/jupyterlite/xeus-wren-kernel/pull/7) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- using jupyter-xeus/xeus-wren instead of DerThorsten/xeus-wren [#6](https://github.com/jupyterlite/xeus-wren-kernel/pull/6) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-wren-kernel/graphs/contributors?from=2021-10-20&to=2021-10-22&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-wren-kernel+involves%3ADerThorsten+updated%3A2021-10-20..2021-10-22&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-wren-kernel+involves%3Ajtpio+updated%3A2021-10-20..2021-10-22&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-wren-kernel/compare/first-commit...6c1c831b3ece43e40c9725519f2453e8e7efc431))

### Maintenance and upkeep improvements

- Ci [#3](https://github.com/jupyterlite/xeus-wren-kernel/pull/3) ([@DerThorsten](https://github.com/DerThorsten))
- using pinnig in Dockerfile [#1](https://github.com/jupyterlite/xeus-wren-kernel/pull/1) ([@DerThorsten](https://github.com/DerThorsten))

### Documentation improvements

- Update screencast and github actions link [#4](https://github.com/jupyterlite/xeus-wren-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-wren-kernel/graphs/contributors?from=2021-10-07&to=2021-10-20&type=c))

[@DerThorsten](https://github.com/search?q=repo%3ADerThorsten%2Fjupyterlite_xeus_wren+involves%3ADerThorsten+updated%3A2021-10-07..2021-10-20&type=Issues) | [@jtpio](https://github.com/search?q=repo%3ADerThorsten%2Fjupyterlite_xeus_wren+involves%3Ajtpio+updated%3A2021-10-07..2021-10-20&type=Issues)
